Learn R Programming

rHpcc (version 1.0)

ECLDataset-class: Class "ECLDataset"

Description

Creates a DATASET definition. The DATASET declaration defines a file of records, on disk or in memory.

Arguments

Fields

name:
Object of class character Class name.
datasetType:
Object of class ECLRecord Input record name.
logicalFileName:
Object of class character A string constant containing the logical file name.
fileType:
Object of class character One of the following keywords, optionally followed by relevant options for that specific type of file: THOR/FLAT, CSV, XML, PIPE.
def:
Object of class character ECl definition/code.

Methods

print():
Prints the ECL code.
addExpression(fieldName):
Used to add ECL definitions.
getDatasetType():
Returns input dataset name.
getName():
Returns class name.

Examples

Run this code
  ## Not run: 
#     ecl1 <- ECL$new(hostName="127.0.0.1")
#     recPerson <- ECLRecord$new(name="Person")
#     recPerson$addField("STRING", "code")
#     recPerson$addField("STRING", "firstName")
#     recPerson$addField("STRING", "lastName")
#     recPerson$addField("STRING", "address")
#     recPerson$addField("STRING", "stateCode")
#     recPerson$addField("STRING", "city")
#     recPerson$addField("STRING", "zip")
#     ecl1$add(recPerson)
#     dsPerson <- ECLDataset$new(name="ds_person", datasetType = recPerson, 
#         logicalFileName ="~ds::person", fileType="CSV")
#     ecl1$add(dsPerson)
#   ## End(Not run)

Run the code above in your browser using DataLab