Learn R Programming

rHpcc (version 1.0)

ECLTOPN: Returns the first count number of records in the sorts order from the recordset.

Description

Returns the first count number of records in the sorts order from the recordset.

Arguments

Examples

Run this code
  ## Not run: 
#     topn <- ECLTOPN$new(name="T1", inDataset = dsRecords, count="5")
#     topn$addField("-Rtot")
#     ecl1$add(iterate)
#   ## End(Not run)

Run the code above in your browser using DataLab