Returns the first count number of records in the sorts order from the recordset.
Arguments
Extends
Class "ECLDataset", directly.
Fields
name:
Object of class character Class name.
datasetType:
Object of class ECLRecord Input record name.
logicalFileName:
Object of class character A string constant containing the logical file name.
fileType:
Object of class character One of the following keywords, optionally followed by relevant options for that specific type of file: THOR/FLAT, CSV, XML, PIPE.
def:
Object of class character ECl definition/code.
inDataset:
Object of class ECLDataset The set of records to process.
count:
Object of class character Expression defining the number of records to return.
Methods
addField(value):
Used to add ECL definitions.
getName():
Returns class name.
print():
Prints the ECL code.
The following methods are inherited (from the corresponding class):
print ("ECLDataset"), getName ("ECLDataset"), getDatasetType ("ECLDataset"), addExpression ("ECLDataset")